#!/bin/bash
ns=$1
registryUrl=$2
Current_DIR=$(cd `dirname $0`; pwd)
ISPECO_DASHBOARD_UI_DIR=$Current_DIR/template/ispeco-dashboard-ui/custom
KEYCLOAK_DIR=$Current_DIR/template/keycloak/custom
YAML_DIR=$Current_DIR/template/yaml
CONFIG_DIR=$Current_DIR/template/config

if [[ -z $ns ]]; then
  echo "namespace is required";
  exit 2;
fi

tinyToolsImageTag="3.12-amd64"
if [[ `arch` =~ "aarch" ]]; then
  tinyToolsImageTag="1.0-arm64";
fi

replaceFileContent() {
  if [[ `echo $operatorSystem | grep -ciw "Darwin"` = 1 ]]
  then
    # Mac
    sed -i '' $@
  else
    # Linux
    sed -i "$@"
  fi
}
getValueFromValues(){
  fileName=$2
  [[ -z $fileName ]] && fileName=$Current_DIR/values_zh.yaml
  index=$(sed -n '/^'"$1":'/=' $fileName)
  if [[ -z $index ]];then
    echo ""
    return $?
  fi
  lineStr=$(cat $fileName | awk 'NR=='"$index"'')
  echo ${lineStr: $(expr length $1)+2}
  return $?
}
replaceConfigValues() {
  valuesFileName=$1;
  configFileName=$2;
  replaceFileContent 's|\${index_title}|'"$(getValueFromValues index_title $valuesFileName)"'|g' $configFileName
  replaceFileContent 's|\${product_name}|'"$(getValueFromValues product_name $valuesFileName)"'|g' $configFileName
  replaceFileContent 's|\${manager_title}|'"$(getValueFromValues manager_title $valuesFileName)"'|g' $configFileName
  replaceFileContent 's|\${index_logo}|'"$(getValueFromValues index_logo $valuesFileName)"'|g' $configFileName
  replaceFileContent 's|\${logo}|'"$(getValueFromValues logo $valuesFileName)"'|g' $configFileName
  replaceFileContent 's|\${copyright}|'"$(getValueFromValues copyright $valuesFileName)"'|g' $configFileName
  replaceFileContent 's|\${version}|'"$(getValueFromValues version $valuesFileName)"'|g' $configFileName
  replaceFileContent 's|\${example_porgram_address}|'"$(getValueFromValues example_porgram_address $valuesFileName)"'|g' $configFileName
}

# collect custom configs
[[ ! -d $KEYCLOAK_DIR ]] && mkdir -p $KEYCLOAK_DIR;
[[ ! -d $ISPECO_DASHBOARD_UI_DIR/image ]] && mkdir -p $ISPECO_DASHBOARD_UI_DIR/image;
cp -r custom/keycloak/* $KEYCLOAK_DIR
cp -r custom/ispeco-dashboard-ui/* $ISPECO_DASHBOARD_UI_DIR/image
cp $CONFIG_DIR/config.json $ISPECO_DASHBOARD_UI_DIR/config_zh.json
cp $CONFIG_DIR/config.json $ISPECO_DASHBOARD_UI_DIR/config_en.json
cp $YAML_DIR/custom-template.yaml $YAML_DIR/custom.yaml;
replaceConfigValues $Current_DIR/values_zh.yaml $ISPECO_DASHBOARD_UI_DIR/config_zh.json
replaceConfigValues $Current_DIR/values_en.yaml $ISPECO_DASHBOARD_UI_DIR/config_en.json

# update title in keycloak
keycloakUrl="http://cloudsuite-keycloak-internal:8080/auth";
title=$(getValueFromValues manager_title $Current_DIR/values_zh.yaml)
replaceFileContent 's|\${KEYCLOAK_URL}|'"$keycloakUrl"'|g' $YAML_DIR/custom.yaml
replaceFileContent 's|\${TITLE}|'"$title"'|g' $YAML_DIR/custom.yaml
replaceFileContent 's|\${REGISTRY_URL}|'"$registryUrl"'|g' $YAML_DIR/custom.yaml
replaceFileContent 's|\${TINY_TOOLS_IMAGE_TAG}|'"$tinyToolsImageTag"'|g' $YAML_DIR/custom.yaml
if [[ -n $(kubectl get job -n $ns | grep keycloak-custom-realm) ]]; then
  kubectl delete job keycloak-custom-realm -n $ns;
fi
kubectl apply -f $YAML_DIR/custom.yaml -n $ns

# copy custom resource to keycloak
keycloakPod=`kubectl get po -n $ns -l app=cloudsuite-keycloak | awk 'NR==2'|awk '{print $1}'`;
kubectl cp $KEYCLOAK_DIR $keycloakPod:/opt/jboss/keycloak/themes/imanager/login/resources -c cloudsuite-keycloak -n $ns;
currentTime=$(date '+%s')
kubectl patch statefulset/cloudsuite-keycloak -n $ns -p '{"spec": {"template": {"metadata": {"labels": {"patch.number": "'$currentTime'"}}}}}'

# copy custom resource to ispeco-dashboard-ui
ispecoUiPod=`kubectl get po -n $ns -l app=cloudsuite-dashboard-ui | awk 'NR==2'|awk '{print $1}'`;
kubectl cp $ISPECO_DASHBOARD_UI_DIR $ispecoUiPod:/etc/icloud/iserver-dashboard-ui -c cloudsuite-dashboard-ui -n $ns;
kubectl delete po $ispecoUiPod -n $ns
echo "customize giscloudsuite successfully"
